import ReactDOM from 'react-dom';
import { scaleBand, scaleLinear, format,nest,quantile } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Box } from './boxRect';
import { MedLine } from './medianLine';
import { CenterLine } from './centerLine';
import { UpLine } from './upperLine';
import { BottomLine } from './bottomLine';

const width = 960;
const height = 500;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };
const boxwidth=100;
const boxOffSet=20;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;


  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

  const yScale = scaleLinear()
    .domain([8,3])
    .range([0, innerHeight]);


   const xScale = scaleBand()
    .range([ 0, width ])
    .domain(["setosa", "versicolor", "virginica"])
    .paddingInner(1)
    .paddingOuter(.5)

    var sumstat = nest() 
    .key(function(d) { return d.species;})
    .rollup(function(d) {
      var q1 = quantile(d.map(function(g) { return g.sepal_length;}).sort(),.25)
      var median = quantile(d.map(function(g) { return g.sepal_length;}).sort(),.5)
      var q3 = quantile(d.map(function(g) { return g.sepal_length;}).sort(),.75)
      var interQuantileRange = q3 - q1
      var min = q1 - 1.5 * interQuantileRange
      var max = q3 + 1.5 * interQuantileRange
      return({q1: q1, median: median, q3: q3, interQuantileRange: interQuantileRange, min: min, max: max})
    })
    .entries(data)
  
  console.log(sumstat);
    
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
       <AxisLeft 
         yScale={yScale}
         innerWidth={innerWidth}
         tickFormat={xAxisTickFormat} 
      />
       <AxisBottom xScale={xScale} />
        <CenterLine
          data={sumstat}
          xScale={xScale}
          yScale={yScale}
  				boxOffSet={boxOffSet}
        />
        <Box
          data={sumstat}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
        />
        <MedLine
          data={sumstat}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          boxOffSet={boxOffSet}
        />
        <UpLine
           data={sumstat}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          boxOffSet={boxOffSet}
        />
        <BottomLine
           data={sumstat}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          boxOffSet={boxOffSet}
        />
        
     </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
